

### Code for downloading the GBIF data for the species for Khaliq et al. 2024 Nature Communications
### This code also calculate STIs
### Imran Khaliq #####
# Set the working directory as "To Source File Location"
library(sp)
library(dplyr)
library(sf)
library(countrycode)
library(CoordinateCleaner)
library(maptools)
library(regos)
library(data.table)
library(rworldmap)
library(raster)




# Read the species names for which data is needed to be downloaded from
# GBIF, this file can be obtained from community data
species_names <- read.csv("../all_species_total.csv")

# Run the loop over all species and save the files as text file
for (i in 1:length(species_names)) {
  
  tryCatch({
    print(i)
    species <- species_names[i]
    #print.Date()
    # maximum number of occurrences that can be downloaded is limited to 100,000
    # for species that have more occurrence, one has to download them
    # separately i.e. manually
    sp_data <- rgbif::occ_data(scientificName=species,limit=99999, hasCoordinate=TRUE, hasGeospatialIssue = FALSE)
  
  
    sp_data <- sp_data$data[,c("name", "decimalLatitude", "decimalLongitude","countryCode",
                               "year", "month", "day","country","basisOfRecord","issues")]
    # 
  
    sp_data$species <- species
    file_name <- paste("../processed_file/all_occ/", species_names[i], ".txt", sep="")
    write.table(sp_data, file_name ,sep="\t",quote=F, row.names=F)
    
  },# add it to your list
  error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
}


# Code for checking the erroneous coordinates and cleaning it ####
species_files<-list.files("../processed_file/all_occ/")

for (i in 1:length(species_files)){
  tryCatch({
    print(i)
    
    species_i <- species_files[i]
    spec_i<- read.delim (species_i, header=TRUE)
    species_name<- unique(spec_i$species)
    spec_i$countryCode <- countrycode(spec_i$countryCode, origin="iso2c", destination = "iso3c")
    spec_ii <- data.frame(spec_i)
    trouble <- clean_coordinates(x = spec_ii, lon = "decimalLongitude",lat = "decimalLatitude",
                                 countries = "countryCode",species = "species",
                                 tests = c("capitals","centroids","gbif","countries"))
    
    trouble_clean <- spec_ii[trouble$.summary,]
    
    
    file_name <- paste("../processed_file/correct_occ_files/", species_files_fish[i], ".txt", sep="")
    write.table(trouble_clean, file_name ,sep="\t",quote=F, row.names=F)
    
  },# add it to your list
  error=function(e){cat("ERROR :",conditionMessage(e), "\n")})
}


# Extracting the climate data and calculating STIs and thermal niche breadths ####

species_files_fresh<-list.files("../processed_file/correct_occ_files/", pattern = ".txt")
# it is advisable to set working directory where clean files are save
setwd("../processed_file/correct_occ_files/")

# Reading the climatic layers ####
mean_values<- raster("climate_layers_mean.nc")
mean_warmest<- raster("mean_warmest.nc")
mean_coldest<- raster("mean_coldest.nc")

# Running the parallel loop on 8 cores ####
species_results_fresh_quarter <- pbapply::pblapply(species_files_fresh, cl = 8L, function(species_file) {
  # for (species_file in species_files_fresh) {
  tryCatch({
    print(species_file)
    
    # Read the data for the current species
    spec_i <- read.delim(species_file, header = TRUE)
    spec_i <- spec_i[!spec_i$basisOfRecord == "PRESERVED_SPECIMEN",]
    spec_i <- spec_i[!is.na(spec_i$decimalLatitude),]
    
    # Extract coordinates
    spec_i_coord <- spec_i[, c("decimalLongitude", "decimalLatitude")]
    coordinates(spec_i_coord) <- ~decimalLongitude + decimalLatitude
    proj4string(spec_i_coord) <- sp::CRS("+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0")
    
    
    # Subset data for each time period
    spec_1990 <- subset(spec_i, year < 1990)
    spec_2000 <- subset(spec_i, year >= 1990 & year <= 2000)
    spec_2010 <- subset(spec_i, year >= 2000 & year <= 2010)
    spec_2020 <- subset(spec_i, year > 2010 )
    propose_2005 <- subset(spec_i,year< 2005)
    
    # Extract temperature information for each time period
    clim_i <- raster::extract(mean_values, spec_i_coord)
    clim_1990 <- raster::extract(mean_values, spec_1990[, c("decimalLongitude", "decimalLatitude")])
    clim_2000 <- raster::extract(mean_values, spec_2000[, c("decimalLongitude", "decimalLatitude")])
    clim_2010 <- raster::extract(mean_values, spec_2010[, c("decimalLongitude", "decimalLatitude")])
    clim_2020 <- raster::extract(mean_values, spec_2020[, c("decimalLongitude", "decimalLatitude")])
    clim_propose_2005 <- raster::extract(mean_values, propose_2005[, c("decimalLongitude", "decimalLatitude")])
    clim_i_max <- raster::extract(mean_warmest, spec_i_coord)
    clim_i_min <- raster::extract(mean_coldest,spec_i_coord)
    
    # Calculate the thermal niche for each time period
    overall_niche_i <- mean(clim_i, na.rm = TRUE)
    niche_1990_i <- mean(clim_1990, na.rm = TRUE)
    niche_2000_i <- mean(clim_2000, na.rm = TRUE)
    niche_2010_i <- mean(clim_2010, na.rm = TRUE)
    niche_2020_i <- mean(clim_2020, na.rm = TRUE)
    propose_2005_i <- mean(clim_propose_2005, na.rm = TRUE)
    # taking the mean of 5 most extreme values
    clim_max_ii<-mean(sort(clim_i_max,decreasing=T,na.last=T)[1:5],na.rm=TRUE) #mean of the warmest 5 cells
    clim_min_ii<-mean(sort(clim_i_min,decreasing=F,na.last=T)[1:5],na.rm=TRUE) #mean of the coldest 5 cells
    
    breadth_i <- clim_max_ii - clim_min_ii
    species_i <- species_file
    # Store the results for the current species
     
    list(
      overall_niche = overall_niche_i,
      niche_1990 = niche_1990_i,
      niche_2000 = niche_2000_i,
      niche_2010 = niche_2010_i,
      niche_2020 = niche_2020_i,
      propose_2005 = propose_2005_i,
      T_5_Maxmin = breadth_i,
      species = species_i
    )
  },# add it to your list
  error = function(e){cat("ERROR :", conditionMessage(e), "\n")})
})


names(species_results_fresh_quarter) = species_files_fresh
# Convert species_results to a data frame
species_results_fresh_quarter1 <- do.call(rbind, lapply(species_results_fresh_quarter, function(x) unlist(x)))
all_species1 <- as.data.frame(species_results_fresh_quarter1)


