
### Code for generating 99 rarefaction samples and calculating CTIs for Khaliq et al. 2024 Nature Communications
# Rarefaction is done on BioTime and RivFishTime data only. 
# These data can be downloaded from respective sites.
### Imran Khaliq #####
# Set the working directory as "To Source File Location"
library(plyr)
library(dplyr)
library(tidyverse)
library(broom)
library(mgcv)
library(lme4)
library(car)
library(MuMIn)
library(moments)
library(rcompanion)
library(wesanderson)
library(jtools)
library(grid)
library(patchwork)
library(ggpubr)

# Rarefaction code borrowed from BioTime webpage ####
rarefysamples<-function(Year, SampleID, Species, Abundance, resamps) {
  #######################################################################
  # takes as input a  Year, SampleID, Species, Abundance and number of resamples
  # which should be in dataframe
  ###########################################################################
  
  rareftab<-data.frame(array(NA,dim=c(0,3)))
  # getting vector with number of samples per year
  nsamples<-c()
  for(y in unique(Year)){
    nsamples<-c(nsamples, length(unique(SampleID[Year==y])))
  }
  t<-1
  minsample<-min(nsamples)
  for(repeats in 1:resamps){
    raref<-data.frame(array(NA,dim=c(1,3)))
    names(raref)<-c("Year","Species","Abundance")
    for(y in unique(Year)){
      #getting samples for this year
      samps<-unique(SampleID[Year==y])
      # re-sampling samples to equalize number of samples
      sam<-as.character(sample(samps,minsample,replace=T))
      # getting data that belongs to bootstraped samples
      rarefyear<-data.frame(SampleID[which(SampleID %in% sam & Year == y)],Species[which(SampleID %in% sam &Year
                                                                                         ==y)],Abundance[which(SampleID %in% sam & Year == y)])
      names(rarefyear)<-c("SampleID", "Species", "Abundance")
      # calculating pooled abundances of each species to store
      spabun<-tapply(as.numeric(rarefyear[,3]),as.character(rarefyear[,2]),sum)
      spar<-data.frame(rep(y, length(spabun)),names(spabun),spabun, row.names=NULL)
      names(spar)<-c("Year","Species","Abundance")
      raref<-rbind(raref,spar)
    }
    # calculating year by species table of abundance
    rareftab<-rbind(rareftab,cbind(rep(repeats,dim(raref)[1]),raref))
  }
  return (rareftab)
}

# biotime data can be downloaded from the BioTime webpage
biotime<-readRDS("../biotime_data11.RData")
length(unique(biotime$ID_Site))
coords<- unique(biotime[,c("lat","lon")])
coords$Site_ID <- as.factor(1:length(coords$lat))
library(tidyverse)
biotime <- left_join(biotime,coords)
TSrf<-list()
query <- biotime
IDs<-unique(query$Site_ID)

for(i in 1:length(IDs)){
  data<-query[query$Site_ID==IDs[i],]
  TSrf[[i]]<-rarefysamples(data$Year, data$SAMPLE_DESC, data$species, data$total, 99) 
}
names(TSrf)<-IDs

rf<-do.call(rbind, TSrf)
rf<-data.frame(rf, ID=rep(names(TSrf), times=unlist(lapply(TSrf, nrow))))
rf<-rf[!is.na(rf$Year),-1]
colnames(coords)[3]<- "ID"
coords$ID_Site <- as.factor(coords$ID)
rf1<- left_join(rf,coords)
rf1<- unique(rf1)

saveRDS(rf1,"../rarefied_biotime_99_10_02_23.RData")

biot <- readRDS("../rarefied_biotime_99_10_02_23.RData")
# Excluding these studies as they have some issues
studies<-c(70,458:465)
# These two studies are the same but of different time period, so combining these
biot$ID[biot$ID== 376]<- 376.77
biot$ID[biot$ID== 377]<- 376.77
biot <- subset(biot,!biot$ID%in%studies)
biot<- biot[,c(1,2,3,6,7,8)]
colnames(biot)[1:6]<- c("r1","Year","species","lat","lon","ID")
biot$ID <- as.character(biot$ID)

# all_species1 contains the thermal niche information generated
# from the GBIF code given above.
all_species1 <- readRDS("../all_species1.RData")

# Rest_of_the_data.RData is all other data that are used under licence
# these data can be obtained from the data providers.
d10 <- readRDS ("Rest_of_the_data.RData")
# Merging rarefied data with rest of the data ####
all_thermo<- vector()
CTI_all<- vector()
rounds<- unique(biot$r1)
for (i in 1:length(rounds)){
  f1 <- rounds[i]
  print(f1)
  biot1 <- biot[biot$r1 == f1,]
  biot1 <- unique(biot1)
  biot1<- biot1[biot1$Year > 1979,]
  biot1 <- merge(biot1, all_species1, by = "species")
  
  biot1$source <- "Biotime"
  
  biot12 <- rbind(biot1, d10)
  all_count_biot1 <- biot12  %>%   # Applying group_by & summarise
    group_by(lat,lon, Year,taxa,realm, source,ID) %>%
    dplyr::summarise(species_count = n_distinct(species),
                     species_STI = n_distinct(species[!is.na(overall_niche)]),
                     percent_sti= (species_STI / species_count)*100)
  
  biot121<- left_join(biot12, all_count_biot1)
  biot121 <- biot121[biot121$species_count >3,]
  biot121 <- biot121[biot121$percent_sti >75,]
  
  CTI_site_all<-ddply(biot121,.(Year, lat, lon,realm,source,taxa,ID),summarise, CTI = mean(overall_niche,na.rm=TRUE),
                      tas=mean(tas, na.rm=TRUE),body = mean(Body, na.rm = TRUE),thermal_breadth = mean(T_5_maxmin, na.rm=T))
  head(CTI_site_all)
  CTI_site_all<- unique(CTI_site_all)
  CTI_site_all <- merge(CTI_site_all, all_count_biot1, by = c("Year","lat","lon","realm","taxa","source","ID"))
  
  CTI_site_all1<- CTI_site_all
  
  CTI_site_all1<- CTI_site_all1[CTI_site_all1$species_count >3,]
  CTI_site_all1<- CTI_site_all1[CTI_site_all1$percent_sti >=75,]
  CTI_site_all1<- CTI_site_all1[CTI_site_all1$Year >=1980,]
  
  # Separating the baseline values
  initial1<-CTI_site_all1 %>% 
    group_by(lat,lon,realm,source,taxa) %>% 
    slice(which.min(Year))
  initial1 <- as.data.frame(initial1)
  
  names(initial1)
  colnames(initial1)[8:11]<- c("base_CTI","base_tas","base_Body","base_niche_breadth")
  
  last_sample1<-CTI_site_all1 %>% 
    group_by(lat,lon,realm,source,taxa) %>% 
    slice(which.max(Year))
  last_sample1 <- as.data.frame(last_sample1)
  
  initial_sample1 <- initial1[,c(1,2,3,4,5,6)]
  colnames(initial_sample1)[1] <- "first_year"
  
  names(last_sample1)
  last_sample1 <- last_sample1[,c(1,2,3,4,5,6)]
  colnames(last_sample1)[1] <- "last_year"
  site_year1 <- left_join(initial_sample1,last_sample1)
  
  ####------------ this to run regression for all sites
  site_year1$diff <- site_year1$last_year - site_year1$first_year
  CTI_site_all1 <- full_join(CTI_site_all1, site_year1)
  CTI_site_all1 <- CTI_site_all1[CTI_site_all1$diff>4,]
  CTI_site_all11<- CTI_site_all1[!is.na(CTI_site_all1$lat),]
  names(CTI_site_all111)
  timeseries_length<- unique(CTI_site_all111[,c("lat","lon","taxa","source","diff","ID")])
  names(d1)
  names(initial1)
  d1<- left_join(d1,initial1)
  d1<- left_join(d1,timeseries_length)
  d1$rf <- f1
  all_thermo <- c(all_thermo,d1)
  # Saving each dataset
  file_name <- paste("Randomized_samples/samples/", f1, ".RData", sep="")
  saveRDS(CTI_site_all111, file_name)
}

