### Code for generating the results and figures for Khaliq et al. 2024 Nature Communications
### This code will generate the figures and statistical analysis in the paper. 
### 

### Imran Khaliq #####
# Set the working directory as "To Source File Location"

rm(list = ls())
#.rs.restartR()
memory.size(max=TRUE)
library(plyr)
library(dplyr)
library(tidyverse)
library(broom)
library(mgcv)
library(lme4)
library(car)
library(MuMIn)
library(moments)
library(rcompanion)
library(wesanderson)
library(jtools)
library(grid)
library(patchwork)
library(ggpubr)

mytheme <- theme_bw() +
  theme(title = element_text(size = 12), 
        plot.title = element_text(face = "bold"),
        strip.text = element_text(size = 14, face = "bold"),
        axis.title = element_text(size = 14, face = "bold"),
        axis.text.x = element_text(size = 14),
        axis.text.y = element_text(size = 14),
        legend.text = element_text(size = 14),
        legend.title = element_text(size = 14, face= "bold"),
        panel.grid.major = element_line(colour = NA),
        panel.grid.minor = element_line(colour = NA)
  ) +
  theme(legend.position="bottom")

theme_set(mytheme)

# function to scale data
m_scale <- function(x) as.numeric(scale(x))

# 'negate' function (opposite for %in%)
`%ni%` <- Negate(`%in%`)

# Reads in the data file generated in the 03_median_values.R code ####
d2<-readRDS("../Data/d1_02_09_23.RData")

# Excluding Mammal and Phytoplankton communities ####
m_p<- c("Mammals","Phytoplankton")
d2<- subset(d2,!d2$taxa%in%m_p)

polar<- d2[abs(d2$lat) > 66.6,]
130/130.60
trop<- d2[abs(d2$lat) < 23.5,]
87/130.60
(13060-(130+87)) / 130.60

# Subsetting polar, tropical and temperate communities ####
d23 <- d2[abs(d2$lat) <66.6,]
d23 <- d23[abs(d23$lat) >23.5,]

# Calculating taxa based mean ####
df1<-groupwiseMean(Thermophilisation ~ taxa,
                   data   = d2,
                   conf   = 0.95,
                   digits = 3)

df1$Realm[df1$taxa == "Birds"]<- "Terrestrial"
df1$Realm[df1$taxa == "Mammals"]<- "Terrestrial"
df1$Realm[df1$taxa == "Plants"]<- "Terrestrial"
df1$Realm[df1$taxa == "Terrestrial_insects"]<- "Terrestrial"
df1$Realm[df1$taxa == "Phytoplankton"]<- "Freshwater"
df1$Realm[df1$taxa == "Fish"]<- "Freshwater"
df1$Realm[df1$taxa == "Aquatic_insects"]<- "Freshwater"
df1$Realm[df1$taxa == "Zooplankton"]<- "Freshwater"

df1$taxa1[df1$taxa == "Birds"]<- "D_Birds"
df1$taxa1[df1$taxa == "Mammals"]<- "A_Mammals"
df1$taxa1[df1$taxa == "Plants"]<- "C_Plants"
df1$taxa1[df1$taxa == "Terrestrial_insects"]<- "B_Terrestrial insects"
df1$taxa1[df1$taxa == "Phytoplankton"]<- "E_Phytoplankton"
df1$taxa1[df1$taxa == "Fish"]<- "G_Fish"
df1$taxa1[df1$taxa == "Aquatic_insects"]<- "H_Aquatic insects"
df1$taxa1[df1$taxa == "Zooplankton"]<- "F_Zooplankton"

# Figure 1 panel b ####
f1b<-ggplot(df1, aes(x=taxa1, y=Mean, color=Realm)) + 
  geom_pointrange(aes(ymin=Trad.lower, ymax=Trad.upper, fatten=2.5), size = 1.5)+
  ylim(-0.08, 0.08)+
  coord_flip()+
  scale_color_manual(values=c("dodgerblue3", "green3"))+
  theme_bw()+
  ylab("Community temperature index change per year")+
  xlab("Taxa")+
  geom_hline(yintercept = 0, linetype="dashed", color = "black", size=0.5)+
  scale_x_discrete(limit = c("A_Mammals","B_Terrestrial insects","C_Plants","D_Birds","E_Phytoplankton","F_Zooplankton","G_Fish","H_Aquatic insects"),
                   labels = c("Mammals","Terrestrial insects","Plants","Birds","Phytoplankton","Zooplankton","Fish","Aquatic insects"))

d2$Realm <- d2$realm
therm_m <- ddply(d2, "Realm", summarise, grp.mean=median(Thermophilisation))
f1a<-ggplot(data=d2, aes(x=Thermophilisation, group=Realm,fill=Realm, color =Realm)) +
  geom_density(aes(fill=Realm),adjust=1.5, alpha=.2,size=1) +
  geom_vline(data=therm_m, aes(xintercept=grp.mean, color=Realm),linetype="solid", size=1)+
  xlab("Thermophilisation (°C year-1)")+
  geom_vline(xintercept = 0, linetype="dashed", color = "black", size=0.3)+
  ylab("Density")+xlim(c(-0.05,0.05))+   
  theme_bw()+theme(legend.position = "none")+
  scale_fill_manual(values=c("dodgerblue3", "green3"))+
  scale_color_manual(values=c("dodgerblue3", "green3")) 

ggarrange(f1a,f1b,
          labels = c("a", "b"),
          ncol = 2, nrow = 1,widths = c(0.6, 1))

# Figure 2 ####
terr <- d2[d2$Realm == "Terrestrial",]
terr <- terr[!terr$taxa == "Mammals",]
# Differences between taxonomic groups ####
terr_axa<-lme(Thermophilisation~taxa,
              data = terr, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(terr_axa)
anova(terr_axa)
terr$Resid <- resid(terr_axa)
SD2_tre<-2*sd(resid(terr_axa))
SD2_tre
terr$Outs<-ifelse(abs(terr$Resid)>SD2_tre, 1, 0)
terr1 <- terr[terr$Outs == 0,]
terr_axa1<-lme(Thermophilisation~taxa,
               data = terr1, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(terr_axa1)
anova(terr_axa1)
fresh <- d2[d2$Realm == "Freshwater",]
fresh0 <- fresh[!fresh$taxa == "Phytoplankton",]
fresh_axa<-lme(Thermophilisation~taxa,
               data = fresh0, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(fresh_axa)
anova(fresh_axa)
fresh0$Resid <- resid(fresh_axa)
SD2_fre<-2*sd(resid(fresh_axa))
SD2_fre
fresh0$Outs<-ifelse(abs(fresh0$Resid)>SD2_fre, 1, 0)
fresh11 <- fresh0[fresh0$Outs == 0,]
fresh_axa1<-lme(Thermophilisation~taxa,
                data = fresh11, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(fresh_axa1)
anova(fresh_axa)

## Effect of drivers at realm level ##
terr <- d2[d2$Realm == "Terrestrial",]
terr <- terr[!terr$taxa == "Mammals",]

names(terr)
terr$swarming <- scale(terr$warming)
terr$sniche <- scale(terr$base_niche_breadth)
terr$sbody <- scale(terr$base_Body)
terr$sspr <- scale(terr$species_STI)
terr$stas <- scale(terr$base_tas)
terr$sdiff <- scale(terr$diff)
terr<- terr[complete.cases(terr),]

library(nlme)
terr_lme<-lme(Thermophilisation~swarming*(sniche*sbody+stas+sspr)+sdiff,
              data = terr, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(terr_lme)
anova(terr_lme)

terr$Resid <- resid(terr_lme)
SD2_terr<-2*sd(resid(terr_lme))
SD2_terr

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
terr$Outs<-ifelse(abs(terr$Resid)>SD2_terr, 1, 0)
terr11 <- terr[terr$Outs == 0,]
terr11$swarming <- scale(terr11$warming)
terr11$sniche <- scale(terr11$base_niche_breadth)
terr11$sbody <- scale(terr11$base_Body)
terr11$ssr <- scale(terr11$species_STI)
terr11$stas <- scale(terr11$base_tas)
terr11$sdiff <- scale(terr11$diff)
terr_lme1<-lme(Thermophilisation~swarming*(sniche*sbody+stas+sspr)+sdiff,
               data = terr11, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(terr_lme1)
r.squaredGLMM(terr_lme1)

anova(terr_lme1)
terr_coefs <- coefTable(terr_lme1, full=F)
terr_coefnames <- row.names(terr_coefs)
terr_coefs <- as.data.frame(terr_coefs)
terr_coefs <- mutate(terr_coefs,
                     coefficient = terr_coefnames,
                     t = Estimate / `Std. Error`,
                     p = round(pt(abs(t), df = nrow(terr_coefs)-1, lower.tail = FALSE),3),
                     lower95 = Estimate - 1.96 * `Std. Error`,
                     upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_terr <-
  terr_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sniche:sbody" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sniche:sbody" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Terrestrial")+
  theme_bw()+ theme(legend.position = "none")
plot_terr

###
fresh <- d2[d2$Realm == "Freshwater",]
names(fresh)
fresh <- fresh[!fresh$taxa == "Phytoplankton",]
fresh$swarming <- scale(fresh$warming)
fresh$sniche <- scale(fresh$base_niche_breadth)
fresh$sbody <- scale(fresh$base_Body)
fresh$ssr <- scale(fresh$species_STI)
fresh$stas <- scale(fresh$base_tas)
fresh$sdiff <- scale(fresh$diff)
#

fresh<- fresh[!is.na(fresh$base_Body),]
fresh<- fresh[!is.na(fresh$ID),]
fresh<- fresh[!is.na(fresh$lat),]
fresh<- fresh[!is.na(fresh$base_niche_breadth),]
fresh$taxa <- as.factor(fresh$taxa)
fresh$ID <- as.factor(fresh$ID)

# 
fresh_lme<-lme(Thermophilisation~swarming*(sniche*sbody+stas+ssr)+sdiff,
               data = fresh, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(maxIter=100,opt = c("optim")))

summary(fresh_lme)

anova(fresh_lme)
fresh$Resid <- resid(fresh_lme)
SD2_fresh<-2*sd(resid(fresh_lme))
SD2_fresh

## Make DF$Outs 1 if a residual is 2 st.deviations from the mean, 0 otherwise
fresh$Outs<-ifelse(abs(fresh$Resid)>SD2_fresh, 1, 0)
fresh11 <- fresh[fresh$Outs == 0,]
fresh11$taxa <- droplevels(fresh11$taxa)

fresh11$swarming <- scale(fresh11$warming)
fresh11$sniche <- scale(fresh11$base_niche_breadth)
fresh11$sbody <- scale(fresh11$base_Body)
fresh11$ssr <- scale(fresh11$species_STI)
fresh11$stas <- scale(fresh11$base_tas)
fresh11$sdiff <- scale(fresh11$diff)
fresh11<- fresh11[!is.na(fresh11$Thermophilisation),]
fresh11<- fresh11[!is.na(fresh11$warming),]
fresh11<- fresh11[!is.na(fresh11$base_Body),]

fresh_lme1<-lme(Thermophilisation~swarming*(sniche*sbody+stas+ssr)+sdiff,
                data = fresh11, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = c("optim")))
summary(fresh_lme1)
r.squaredGLMM(fresh_lme1)
fresh_data <- fresh_lme1$data

summary(fresh_lme1)

fresh_coefs <- coefTable(fresh_lme1, full=F)
fresh_coefnames <- row.names(fresh_coefs)
fresh_coefs <- as.data.frame(fresh_coefs)
fresh_coefs <- mutate(fresh_coefs,
                      coefficient = fresh_coefnames,
                      t = Estimate / `Std. Error`,
                      p = round(pt(abs(t), df = nrow(fresh_coefs)-1, lower.tail = FALSE),3),
                      lower95 = Estimate - 1.96 * `Std. Error`,
                      upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_fresh <-
  fresh_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "ssr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sniche:sbody" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:ssr" = "B_Warming:species_richness",
                                     "swarming:sniche:sbody" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Freshwater")+
  theme_bw()+ theme(legend.position = "none")

plot_fresh

Birds1 <- d2[d2$taxa == "Birds",]
Birds1$swarming <- scale(Birds1$warming)
Birds1$sbody <- scale(Birds1$base_Body)
Birds1$sniche <- scale(Birds1$base_niche_breadth)
Birds1$sspr <- scale(Birds1$species_STI)
Birds1$stas <- scale(Birds1$base_tas)
Birds1$sdiff <- scale(Birds1$diff)

# 
birds_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                data = Birds1, random=~1|ID,correlation=corGaus(form = ~ lat + lon),
                control = lmeControl(maxIter=100,opt = c("optim")))
summary(birds_lme1)
#
Birds1$Resid<-resid(birds_lme1)
# Find out what 2 standard deviations is and save it to SD2
SD2_birds<-2*sd(resid(birds_lme1))
SD2_birds
#
# # Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
Birds1$Outs<-ifelse(abs(Birds1$Resid)>SD2_birds, 1, 0)
Birds11 <- Birds1[Birds1$Outs == 0,]
Birds11$swarming <- scale(Birds11$warming)
Birds11$sbody <- scale(Birds11$base_Body)
Birds11$sniche <- scale(Birds11$base_niche_breadth)
Birds11$sspr <- scale(Birds11$species_STI)
Birds11$stas <- scale(Birds11$base_tas)
Birds11$sdiff <- scale(Birds11$diff)
#
birds_lme11<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                 data = Birds11, random=~1|ID,correlation=corGaus(form = ~ lat + lon),
                 control = lmeControl(maxIter=100,opt = c("optim")))
summary(birds_lme11)
r.squaredGLMM(birds_lme11)

bird_coefs <- coefTable(birds_lme11, full=F)
bird_coefnames <- row.names(bird_coefs)
bird_coefs <- as.data.frame(bird_coefs)
bird_coefs <- mutate(bird_coefs,
                     coefficient = bird_coefnames,
                     t = Estimate / `Std. Error`,
                     p = round(pt(abs(t), df = nrow(bird_coefs)-1, lower.tail = FALSE),3),
                     lower95 = Estimate - 1.96 * `Std. Error`,
                     upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_bird <-
  bird_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Birds")+
  theme_bw()+ theme(legend.position = "none")

plot_bird
####


Mammals1 <- d2[d2$taxa == "Mammals",]
Mammals1$swarming <- scale(Mammals1$warming)
Mammals1$sbody <- scale(Mammals1$base_Body)
Mammals1$sniche <- scale(Mammals1$base_niche_breadth)
Mammals1$sspr <- scale(Mammals1$species_STI)
Mammals1$stas <- scale(Mammals1$base_tas)
Mammals1$sdiff <- scale(Mammals1$diff)

library(nlme)
mammals_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                 data = Mammals1,random= ~1|ID,correlation=corGaus(form = ~ lat + lon))
summary(mammals_lme)
hist(mammals_lme$residuals)

Mammals1$Resid<-resid(mammals_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_mammals<-2*sd(resid(mammals_lme))
SD2_mammals
# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
Mammals1$Outs<-ifelse(abs(Mammals1$Resid)>SD2_mammals, 1, 0)

Mammals11 <- Mammals1[Mammals1$Outs == 0,]
Mammals11$swarming <- scale(Mammals11$warming)
Mammals11$sbody <- scale(Mammals11$base_Body)
Mammals11$sniche <- scale(Mammals11$base_niche_breadth)
Mammals11$sspr <- scale(Mammals11$species_STI)
Mammals11$stas <- scale(Mammals11$base_tas)
Mammals11$sdiff <- scale(Mammals11$diff)

mammals_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                  data = Mammals11,random= ~1|ID, correlation=corGaus(form = ~ lat +lon), control = lmeControl(opt = "optim"))
summary(mammals_lme1)

ma_coefs <- coefTable(mammals_lme1, full=F)
coefnames <- row.names(ma_coefs)
ma_coefs <- as.data.frame(ma_coefs)
ma_coefs <- mutate(ma_coefs,
                   coefficient = coefnames,
                   t = Estimate / `Std. Error`,
                   p = round(pt(abs(t), df = nrow(ma_coefs)-1, lower.tail = FALSE),3),
                   lower95 = Estimate - 1.96 * `Std. Error`,
                   upper95 = Estimate + 1.96 * `Std. Error`)
# Plot for the yearly dataset
plot_mammals <-
  ma_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Mammals")+
  theme_bw()+ theme(legend.position = "none")
plot_mammals

insects1 <- d2[d2$taxa == "Terrestrial_insects",]
insects1$swarming <- scale(insects1$warming)
insects1$sbody <- scale(insects1$base_Body)
insects1$sniche <- scale(insects1$base_niche_breadth)
insects1$sspr <- scale(insects1$species_STI)
insects1$stas <- scale(insects1$base_tas)
insects1$sdiff <- scale(insects1$diff)
insects1 <- insects1[!is.na(insects1$sbody),]
insects1 <- insects1[complete.cases(insects1),]

insects_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                 data = insects1,random=~1|ID, correlation=corGaus(form = ~ lat +lon), control = lmeControl(opt = "optim"))
summary(insects_lme)
hist(insects_lme$residuals)
insects1$Resid <- resid(insects_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_insect<-2*sd(resid(insects_lme))
SD2_insect
# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
insects1$Outs<-ifelse(abs(insects1$Resid)>SD2_insect, 1, 0)

insects11 <- insects1[insects1$Outs == 0,]
insects11$swarming <- scale(insects11$warming)
insects11$sbody <- scale(insects11$base_Body)
insects11$sniche <- scale(insects11$base_niche_breadth)
insects11$sspr <- scale(insects11$species_STI)
insects11$stas <- scale(insects11$base_tas)
insects11$sdiff <- scale(insects11$diff)
insects11 <- insects11[!is.na(insects11$sbody),]

insects_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                  data = insects11,random = ~1|ID, correlation=corGaus(form = ~ lat+lon))
summary(insects_lme1)
r.squaredGLMM(insects_lme1)

insect_coefs <- coefTable(insects_lme1, full=F)
insect_coefnames <- row.names(insect_coefs)
insect_coefs <- as.data.frame(insect_coefs)
insect_coefs <- mutate(insect_coefs,
                       coefficient = insect_coefnames,
                       t = Estimate / `Std. Error`,
                       p = round(pt(abs(t), df = nrow(insect_coefs)-1, lower.tail = FALSE),3),
                       lower95 = Estimate - 1.96 * `Std. Error`,
                       upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_insects <-
  insect_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Terrestrial Insects")+
  theme_bw()+ theme(legend.position = "none")

plot_insects

plants1 <- d2[d2$taxa == "Plants",]

names(plants1)

plants1$swarming <- scale(plants1$warming)
plants1$sbody <- scale(plants1$base_Body)
plants1$sniche <- scale(plants1$base_niche_breadth)
plants1$sspr <- scale(plants1$species_STI)
plants1$stas <- scale(plants1$base_tas)
plants1$sdiff <- scale(plants1$diff)

plants_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                data = plants1, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon),
                control = glsControl(opt = "optim"))
summary(plants_lme)
hist(plants_lme$residuals)

plants1$Resid<-resid(plants_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_plant<-2*sd(resid(plants_lme))
SD2_plant

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
plants1$Outs<-ifelse(abs(plants1$Resid)>SD2_plant, 1, 0)

plants11 <- plants1[plants1$Outs == 0,]
plants11$swarming <- scale(plants11$warming)
plants11$sbody <- scale(plants11$base_Body)
plants11$sniche <- scale(plants11$base_niche_breadth)
plants11$sspr <- scale(plants11$species_STI)
plants11$stas <- scale(plants11$base_tas)
plants11$sdiff <- scale(plants11$diff)

plants_lme11<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                  data = plants11,random=~1|ID, correlation=corGaus(1,form = ~ lat + lon),
                  control = lmeControl(opt = "optim"))
summary(plants_lme11)
r.squaredGLMM(plants_lme11)
res.table.plants <- as.data.frame(coef(summary(plants_lme11)))
write.csv(res.table.plants,"plants_results_22_08_23.csv" )

plant_coefs <- coefTable(plants_lme11, full=F)
plant_coefnames <- row.names(plant_coefs)
plant_coefs <- as.data.frame(plant_coefs)
plant_coefs <- mutate(plant_coefs,
                      coefficient = plant_coefnames,
                      t = Estimate / `Std. Error`,
                      p = round(pt(abs(t), df = nrow(plant_coefs)-1, lower.tail = FALSE),3),
                      lower95 = Estimate - 1.96 * `Std. Error`,
                      upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_plant <-
  plant_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Plants")+
  theme_bw()+ theme(legend.position = "none")

plot_plant

fish1 <- d2[d2$taxa == "Fish",]
fish1$swarming <- scale(fish1$warming)
fish1$sbody <- scale(fish1$base_Body)
fish1$sniche <- scale(fish1$base_niche_breadth)
fish1$sspr <- scale(fish1$species_STI)
fish1$stas <- scale(fish1$base_tas)
fish1$sdiff <- scale(fish1$diff)

fish_lme<-lme(Thermophilisation~swarming*(sbody*sniche+sspr+stas)+sdiff,
              data = fish1, random=~1|ID, correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(fish_lme)

fish1$Resid<-resid(fish_lme)

# Find out what 2 standard deviations is and save it to SD2
SD2_fish1<-2*sd(resid(fish_lme))
SD2_fish1

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
fish1$Outs<-ifelse(abs(fish1$Resid)>SD2_fish1, 1, 0)
fish11 <- fish1[fish1$Outs == 0,]
fish11$swarming <- scale(fish11$warming)
fish11$sbody <- scale(fish11$base_Body)
fish11$sniche <- scale(fish11$base_niche_breadth)
fish11$sspr <- scale(fish11$species_STI)
fish11$stas <- scale(fish11$base_tas)
fish11$sdiff <- scale(fish11$diff)
# 
fish_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
               data = fish11, random=~1|ID, correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(fish_lme1)
r.squaredGLMM(fish_lme1)

fish_coefs <- coefTable(fish_lme1, full=F)
fish_coefnames <- row.names(fish_coefs)
fish_coefs <- as.data.frame(fish_coefs)
fish_coefs <- mutate(fish_coefs,
                     coefficient = fish_coefnames,
                     t = Estimate / `Std. Error`,
                     p = round(pt(abs(t), df = nrow(fish_coefs)-1, lower.tail = FALSE),3),
                     lower95 = Estimate - 1.96 * `Std. Error`,
                     upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_fish <-
  fish_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red"))+
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Fish")+
  theme_bw()+ theme(legend.position = "none")

plot_fish

# 

phy1 <- d2[d2$taxa == "Phytoplankton",]
phy1$swarming <- scale(phy1$warming)
phy1$sbody <- scale(phy1$base_Body)
phy1$sniche <- scale(phy1$base_niche_breadth)
phy1$sspr <- scale(phy1$species_count)
phy1$stas <- scale(phy1$base_tas)
phy1$sdiff <- scale(phy1$diff)

phy1 <-phy1[!is.na(phy1$sbody),]
phy_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
             data = phy1, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon))
summary(phy_lme)


phy1$Resid<-resid(phy_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_phy1<-2*sd(resid(phy_lme))
SD2_phy1
# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
phy1$Outs<-ifelse(abs(phy1$Resid)>SD2_phy1, 1, 0)
phy11 <- phy1[phy1$Outs == 0,]
phy11$swarming <- scale(phy11$warming)
phy11$sbody <- scale(phy11$base_Body)
phy11$sniche <- scale(phy11$base_niche_breadth)
phy11$sspr <- scale(phy11$species_count)
phy11$stas <- scale(phy11$base_tas)
phy11$sdiff <- scale(phy11$diff)
phy_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
              data = phy11,random=~1|ID, correlation=corGaus(1,form = ~ lat + lon))
summary(phy_lme1)

phy_coefs <- coefTable(phy_lme1, full=F)
phy_coefnames <- row.names(phy_coefs)
phy_coefs <- as.data.frame(phy_coefs)
phy_coefs <- mutate(phy_coefs,
                    coefficient = phy_coefnames,
                    t = Estimate / `Std. Error`,
                    p = round(pt(abs(t), df = nrow(phy_coefs)-1, lower.tail = FALSE),3),
                    lower95 = Estimate - 1.96 * `Std. Error`,
                    upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_phy <-
  phy_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red"))+
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Phytoplankton")+
  theme_bw()+ theme(legend.position = "none")
plot_phy



zoo1 <- d2[d2$taxa == "Zooplankton",]
zoo1$swarming <- scale(zoo1$warming)
zoo1$sbody <- scale(zoo1$base_Body)
zoo1$sniche <- scale(zoo1$base_niche_breadth)
zoo1$sspr <- scale(zoo1$species_STI)
zoo1$stas <- scale(zoo1$base_tas)
zoo1$sdiff <- scale(zoo1$diff)

zoo1<- zoo1[!is.na(zoo1$sbody),]
zoo1 <- zoo1[complete.cases(zoo1),]
zoo_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
             data = zoo1, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon),
             control = lmeControl(opt = "optim"),na.action=na.omit)
summary(zoo_lme)
hist(zoo_lme$residuals)
zoo1$Resid<-resid(zoo_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_zoo1<-2*sd(resid(zoo_lme))
SD2_zoo1

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
zoo1$Outs<-ifelse(abs(zoo1$Resid)>SD2_zoo1, 1, 0)
zoo11 <- zoo1[zoo1$Outs == 0,]

zoo11$swarming <- scale(zoo11$warming)
zoo11$sbody <- scale(zoo11$base_Body)
zoo11$sniche <- scale(zoo11$base_niche_breadth)
zoo11$sspr <- scale(zoo11$species_STI)
zoo11$stas <- scale(zoo11$base_tas)
zoo11$sdiff <- scale(zoo11$diff)

zoo_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
              data = zoo11, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(zoo_lme1)
r.squaredGLMM(zoo_lme1)

zoo_coefs <- coefTable(zoo_lme1, full=F)
zoo_coefnames <- row.names(zoo_coefs)
zoo_coefs <- as.data.frame(zoo_coefs)
zoo_coefs <- mutate(zoo_coefs,
                    coefficient = zoo_coefnames,
                    t = Estimate / `Std. Error`,
                    p = round(pt(abs(t), df = nrow(zoo_coefs)-1, lower.tail = FALSE),3),
                    lower95 = Estimate - 1.96 * `Std. Error`,
                    upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_zoo <-
  zoo_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Zooplankton")+
  theme_bw()+ theme(legend.position = "none")

plot_zoo




aqua1 <- d2[d2$taxa == "Aquatic_insects",]
aqua1<- unique(aqua1)
aqua1$swarming <- scale(aqua1$warming)
aqua1$sbody <- scale(aqua1$base_Body)
aqua1$sniche <- scale(aqua1$base_niche_breadth)
aqua1$sspr <- scale(aqua1$species_STI)
aqua1$stas <- scale(aqua1$base_tas)
aqua1$sdiff <- scale(aqua1$diff)
aqua1<- aqua1[!is.nan(aqua1$base_Body),]
aqua1 <- aqua1[complete.cases(aqua1),]
aqua_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
              data = aqua1,random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(aqua_lme)

aqua1$Resid<-resid(aqua_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_aqua1<-2*sd(resid(aqua_lme))
SD2_aqua1

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
aqua1$Outs<-ifelse(abs(aqua1$Resid)>SD2_aqua1, 1, 0)
aqua11 <- aqua1[aqua1$Outs == 0,]
aqua11$swarming <- scale(aqua11$warming)
aqua11$sbody <- scale(aqua11$base_Body)
aqua11$sniche <- scale(aqua11$base_niche_breadth)
aqua11$sspr <- scale(aqua11$species_STI)
aqua11$stas <- scale(aqua11$base_tas)
aqua11$sdiff <- scale(aqua11$diff)

aqua_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
               data = aqua11,random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(aqua_lme1)
r.squaredGLMM(aqua_lme1)

aqua_coefs <- coefTable(aqua_lme1, full=F)
aqua_coefnames <- row.names(aqua_coefs)
aqua_coefs <- as.data.frame(aqua_coefs)
aqua_coefs <- mutate(aqua_coefs,
                     coefficient = aqua_coefnames,
                     t = Estimate / `Std. Error`,
                     p = round(pt(abs(t), df = nrow(aqua_coefs)-1, lower.tail = FALSE),3),
                     lower95 = Estimate - 1.96 * `Std. Error`,
                     upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_aqua <-
  aqua_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","red","blue")) + 
  scale_color_manual(values=c("grey","red","blue"))+
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Aquatic insects")+
  theme_bw()+ theme(legend.position = "none")

plot_aqua



ggarrange(plot_terr,plot_plant,plot_insects,plot_bird,plot_fresh,
          plot_zoo,plot_aqua,plot_fish,
          labels = c("a", "b","c","d","e","f","g","h"),
          ncol = 4, nrow = 2)



# Figure 3 ####

f3_wide<-readRDS("../Data/Figure_3_final.RData")

f3_long <- pivot_longer(
  f3_wide,
  cols = (2:4),
  names_to = "Fate",
  values_to = "value"
)
m_p<- c("Mammals","Phytoplankton")

f3_long$Realm[f3_long$taxa == "Plants"]<- "Terrestrial"
f3_long$Realm[f3_long$taxa == "Terrestrial_insects"]<- "Terrestrial"
f3_long$Realm[f3_long$taxa == "Birds"]<- "Terrestrial"
f3_long$Realm[f3_long$taxa == "Mammals"]<- "Terrestrial"
f3_long$Realm[f3_long$taxa == "Phytoplankton"]<- "Freshwater"
f3_long$Realm[f3_long$taxa == "Zooplankton"]<- "Freshwater"
f3_long$Realm[f3_long$taxa == "Aquatic_insects"]<- "Freshwater"
f3_long$Realm[f3_long$taxa == "Fish"]<- "Freshwater"

p0<-f3_long[f3_long$Realm == "Terrestrial",]
p1<-f3_long[f3_long$taxa == "Plants",]
p2<-f3_long[f3_long$taxa == "Terrestrial_insects",]
p3<-f3_long[f3_long$taxa == "Birds",]  
p4<-f3_long[f3_long$taxa == "Mammals",]
p05<-f3_long[f3_long$Realm == "Freshwater",]
p5<-f3_long[f3_long$taxa == "Phytoplankton",]
p6<-f3_long[f3_long$taxa == "Zooplankton",]
p7<-f3_long[f3_long$taxa == "Aquatic_insects",]  
p8<-f3_long[f3_long$taxa == "Fish",]


p01<-ggplot(p0, aes(x=Fate, y=value, color = value)) + 
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p11<-ggplot(p1, aes(x=Fate, y=value, color = value)) + 
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p21<-ggplot(p2, aes(x=Fate, y=value, color = value)) + 
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p31<-ggplot(p3, aes(x=Fate, y=value, color = value)) + 
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p41<-ggplot(p4, aes(x=Fate, y=value, color = value)) +
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p051<-ggplot(p05, aes(x=Fate, y=value, color = value)) + 
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p51<-ggplot(p5, aes(x=Fate, y=value, color = value)) +
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p61<-ggplot(p6, aes(x=Fate, y=value, color = value)) + 
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p71<-ggplot(p7, aes(x=Fate, y=value, color = value)) + 
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")

p81<-ggplot(p8, aes(x=Fate, y=value, color = value)) + 
  geom_point(position = position_jitter(seed = 0.5,width = 0.2))+
  scale_color_gradient2(midpoint=0, low="blue", mid="grey",
                        high="red" )+
  ylim(-10,10)+
  geom_violin(alpha=0.01, color = "black")+
  geom_hline(yintercept=0, linetype="dashed", color = "black", size=1)+
  theme_bw()+ theme(legend.position = "none")


library(ggpubr)
ggarrange(p01,p11,p21,p31,p051,p61,p71,p81,
          labels = c("a", "b","c","d","e","f","g","h"),
          ncol = 4, nrow = 2)

# Extended Data Figure 6 ####
ggarrange(p41,p51,
          labels = c("a", "b"),
          ncol = 1, nrow = 2)


### calculate binom test for each group

figure_3_group_n_STI<-f3_wide%>%
  group_by(taxa)%>%
  dplyr::summarise( A_P_posi = length(which(add_persist > 0)),
                    A_P_nega = length(which(add_persist < 0)),
                    P_L_posi = length(which(persist_lost > 0)),
                    P_L_nega = length(which(persist_lost < 0)),
                    A_L_posi = length(which(add_lost > 0 )),
                    A_L_nega = length(which(add_lost < 0)))



f3_wide$Realm[f3_wide$taxa == "Plants"]<- "Terrestrial"
f3_wide$Realm[f3_wide$taxa == "Terrestrial_insects"]<- "Terrestrial"
f3_wide$Realm[f3_wide$taxa == "Birds"]<- "Terrestrial"
f3_wide$Realm[f3_wide$taxa == "Mammals"]<- "Terrestrial"
f3_wide$Realm[f3_wide$taxa == "Phytoplankton"]<- "Freshwater"
f3_wide$Realm[f3_wide$taxa == "Zooplankton"]<- "Freshwater"
f3_wide$Realm[f3_wide$taxa == "Aquatic_insects"]<- "Freshwater"
f3_wide$Realm[f3_wide$taxa == "Fish"]<- "Freshwater"

f3_wide1 <- subset(f3_wide, !f3_wide$taxa%in%m_p)
figure_5_realm_n_STI<-f3_wide1%>%
  group_by(Realm)%>%
  dplyr::summarise( A_P_posi = length(which(add_persist > 0)),
                    A_P_nega = length(which(add_persist < 0)),
                    P_L_posi = length(which(persist_lost > 0)),
                    P_L_nega = length(which(persist_lost < 0)),
                    A_L_posi = length(which(add_lost > 0 )),
                    A_L_nega = length(which(add_lost < 0)))


# terrestrial
binom.test(2585, 6314) # A_P: 2585+3729, p<0.001
binom.test(3441,6272) # A_L: 3441 + 2831, p<0.001
binom.test(3935,6314) # P_L: 3935+2379, p<0.001



# freshwater
binom.test(3764,6444) # A_P: 3764+2680, p<0.001
binom.test(3069,5987) # A_L: 3069 + 2918, p = 0.052
binom.test(2738,6446) # P_L: 2738+3708, p<0.001


# Plants
binom.test(435,678) # A_P: 435+243, p<0.001
binom.test(428,624) # A_L: 428 + 196, p<0.001
binom.test(382,678) # P_L: 382+296, p<0.001


# Terrestrial insect
binom.test(371,713) # A_P: 371+342, p = 0.294
binom.test(427,707) # A_L: 427 + 280, p<0.001
binom.test(409,718) # P_L: 409+305, p<0.001


# Birds
binom.test(1779,4923) # A_P: 1779+3144, p<0.001
binom.test(2586,4941) # A_L: 2586 + 2355, p=0.001
binom.test(3144,4922) # P_L: 3144+1778, p<0.001


# #Mammals
# binom.test(14,35) # A_P: 14+21, p=31, 
# binom.test(15,34) # A_L: 15 + 19, p=0.6
# binom.test(26,35) # P_L: 26+9, p= 0.005

# #Phytoplankton
# binom.test(16,28) # A_P: 16+12, p=0.72
# binom.test(2,28) # A_L: 2 + 26, p<0.001
# binom.test(9,28) # P_L: 9+19, p = 0.17

#Zooplankton
binom.test(86,154) # A_P: 86+68, p=0.17
binom.test(64,230) # A_L: 64 + 166, p = p<0.001
binom.test(65,152) # P_L: 65+87, p =.08


#Aquatic insects
binom.test(252,422) # A_P: 252+170, p<0.001, 
binom.test(243,410) # A_L: 243 + 167, p<0.001
binom.test(214,417) # P_L: 214+203, p = 0.62

#Fish
binom.test(3426,5868) # A_P: 3426+2442, p<0.001
binom.test(2762,5347) # A_L: 2762 + 2585, p= 0.01
binom.test(2459,5877) # P_L: 2459+3418, p<0.001



# Figure Extended Data 1 ####
temp_ch <- readRDS("../Data/temp_pvalue.RData")
temp_ch$p.value[is.nan(temp_ch$p.value)]<- 0
dterrestrial<- temp_ch[temp_ch$realm == "Terrestrial",]
dfreshwater<- temp_ch[temp_ch$realm == "Freshwater",]
world <- map_data("world")
world<- world[world$lat > -60,]


dter_n <- dterrestrial[dterrestrial$p.value > 0.05,]
dterrestrial <- dterrestrial[dterrestrial$p.value < 0.05,]

mid<- 0


p1<-ggplot() +
  geom_map(data = world, map = world, aes(long, lat, map_id = region),bg="grey", fill = "grey")+
  geom_point(data= dter_n ,shape = 20,size=0.5,  aes(lon, lat))+
  geom_point(data= dterrestrial ,shape = 20,size=0.5,  aes(lon, lat, color = warming))+
  theme_bw()+ggtitle("Terrestrial")+
  scale_color_gradient2(midpoint=mid, low="blue",mid="white",high="red")+ 
  theme(plot.title = element_text(hjust=0.5))+
  geom_jitter()+xlab("Longitude")+ylab("Latitude")

dfre_n <- dfreshwater[dfreshwater$p.value > 0.05,]
dfreshwater <- dfreshwater[dfreshwater$p.value < 0.05,]
# to exclude the outliers
p2<-ggplot() +
  geom_map(data = world, map = world, aes(long, lat, map_id = region),bg="grey", fill = "grey") +
  geom_point(data= dfre_n ,shape = 20,size=0.5,  aes(lon, lat))+
  geom_point(data= dfreshwater ,shape = 20,size=0.5,  aes(lon, lat, color = warming))+
  theme_bw()+ggtitle("Freshwater")+
  scale_color_gradient2(midpoint=mid, low="blue",mid="white",high="red")+ 
  theme(plot.title = element_text(hjust=0.5))+
  geom_jitter()+xlab("Longitude")+ylab("Latitude")


dfrealm<-groupwiseMean(warming ~ realm,
                       data   = d2,
                       conf   = 0.95,
                       digits = 3)

temp_m <- ddply(d2, "Realm", summarise, grp.mean=median(warming))
f_Sc<-ggplot(data=d2, aes(x=warming, group=Realm,fill=Realm, color =Realm)) +
  geom_density(aes(fill=Realm),adjust=1.5, alpha=.2,size=1) +
  geom_vline(data=temp_m, aes(xintercept=grp.mean, color=Realm),linetype="solid", size=1)+
  xlab("Temperature change (°C year-1)")+
  geom_vline(xintercept = 0, linetype="dashed", color = "black", size=0.3)+
  ylab("Density")+xlim(c(-0.2,0.25))+   
  theme_bw()+
  scale_fill_manual(values=c("dodgerblue3", "green3"))+
  scale_color_manual(values=c("dodgerblue3", "green3")) 
inset_sc<-ggplot(dfrealm, aes(x=realm, y=Mean, color=realm)) + 
  geom_pointrange(aes(ymin=Trad.lower, ymax=Trad.upper, fatten=2.5), size = 1.5)+
  coord_flip()+xlab("")+
  scale_color_manual(values=c("dodgerblue3", "green3"))+
  theme_bw()+ ylab("Δ Temperature (°C)")+theme(legend.position="none",axis.text.y=element_blank())

fsc<-ggdraw() +
  draw_plot(f_Sc) +
  draw_plot(inset_sc, x = 0.08, y = 0.6, width = .28, height = .28)



ggarrange(p1,p2,fsc,
          labels = c("a", "b","c"),
          ncol = 1, nrow = 3)


# Figure Extended Data 2 ####
df_FE2<-readRDS("../Data/d1_02_09_23.RData")


df1_FE2<-groupwiseMean(Thermophilisation ~ taxa,
                   data   = df_FE2,
                   conf   = 0.95,
                   digits = 3)


df1_FE2$Realm[df1_FE2$taxa == "Birds"]<- "Terrestrial"
df1_FE2$Realm[df1_FE2$taxa == "Mammals"]<- "Terrestrial"
df1_FE2$Realm[df1_FE2$taxa == "Plants"]<- "Terrestrial"
df1_FE2$Realm[df1_FE2$taxa == "Terrestrial_insects"]<- "Terrestrial"
df1_FE2$Realm[df1_FE2$taxa == "Phytoplankton"]<- "Freshwater"
df1_FE2$Realm[df1_FE2$taxa == "Fish"]<- "Freshwater"
df1_FE2$Realm[df1_FE2$taxa == "Aquatic_insects"]<- "Freshwater"
df1_FE2$Realm[df1_FE2$taxa == "Zooplankton"]<- "Freshwater"


df1_FE2$taxa1[df1_FE2$taxa == "Birds"]<- "D_Birds"
df1_FE2$taxa1[df1_FE2$taxa == "Mammals"]<- "A_Mammals"
df1_FE2$taxa1[df1_FE2$taxa == "Plants"]<- "C_Plants"
df1_FE2$taxa1[df1_FE2$taxa == "Terrestrial_insects"]<- "B_Terrestrial insects"
df1_FE2$taxa1[df1_FE2$taxa == "Phytoplankton"]<- "E_Phytoplankton"
df1_FE2$taxa1[df1_FE2$taxa == "Fish"]<- "G_Fish"
df1_FE2$taxa1[df1_FE2$taxa == "Aquatic_insects"]<- "H_Aquatic insects"
df1_FE2$taxa1[df1_FE2$taxa == "Zooplankton"]<- "F_Zooplankton"

ggplot(df1_FE2, aes(x=taxa1, y=Mean, color=Realm)) + 
  geom_pointrange(aes(ymin=Trad.lower, ymax=Trad.upper, fatten=2.5), size = 1.5)+
  ylim(-0.08, 0.08)+
  coord_flip()+
  scale_color_manual(values=c("dodgerblue3", "green3"))+
  theme_bw()+
  ylab("Community temperature index change per year")+
  xlab("Taxa")+
  geom_hline(yintercept = 0, linetype="dashed", color = "black", size=0.5)+
  scale_x_discrete(limit = c("A_Mammals","B_Terrestrial insects","C_Plants","D_Birds","E_Phytoplankton","F_Zooplankton","G_Fish","H_Aquatic insects"),
                   labels = c("Mammals","Terrestrial insects","Plants","Birds","Phytoplankton","Zooplankton","Fish","Aquatic insects"))


# Figure Extended Data 3 ####

exclude <- c("Phytoplankton","Mammals")
d3<- subset(d2,!d2$taxa%in%exclude)
temp_realm<-lme(Thermophilisation~warming*Realm,
                data = d3, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))

# 
# summary(temp_realm)
d3$Resid<- resid(temp_realm)
SD2_temp<- 2*sd(resid(temp_realm))
d3$outs<- ifelse(abs(d3$Resid)>SD2_temp,1,0)
d33<-d3[d3$outs==0,]
temp_realm2<-lme(Thermophilisation~warming*Realm,
                 data = d33, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(temp_realm2)

d11<- temp_realm2[[18]]
effect_realms1<- effects::effect("warming*Realm",temp_realm2,KR=T)

effect_realms2 <- as.data.frame(effect_realms1)
effect_realms2$colour[effect_realms2$realm  == "Terrestrial"]<-"green3"
effect_realms2$colour[effect_realms2$realm  == "Freshwater"]<-"dodgerblue3"

mycol <- c("dodgerblue","green3")

ggplot(effect_realms2, aes(warming, linetype=Realm, color = Realm)) +
  scale_color_manual(values=c("dodgerblue", "green3"))+
  geom_line(aes(y = fit, group=factor(Realm)), size=1.2) +
  geom_line(aes(y = lower,group=factor(Realm)), linetype =3) +
  geom_line(aes(y = upper,group=factor(Realm)), linetype =3) +
  geom_ribbon(aes(ymin=lower,ymax=upper), fill="lightgrey", alpha=0.4) +
  xlab("Temperature change [°C]") +
  ylab("Marginal effects on thermophilisation")+ theme(text = element_text(size = 100),legend.position="none")+
  labs(color='Realm', tag="a") + theme_minimal()

# Extended Data Figure 4 ####

d23 <- d2[abs(d2$lat) <66.6,]
d23 <- d23[abs(d23$lat) >23.5,]

terr_temp <- d23[d23$Realm == "Terrestrial",]
terr_temp <- terr_temp[!terr_temp$taxa == "Mammals",]
fresh_temp <- d23[d23$Realm == "Freshwater",]
fresh_temp <- fresh_temp[!fresh_temp$taxa == "Phytoplankton",]

names(terr)
terr_temp$swarming <- scale(terr_temp$warming)
terr_temp$sniche <- scale(terr_temp$base_niche_breadth)
terr_temp$sbody <- scale(terr_temp$base_Body)
terr_temp$sspr <- scale(terr_temp$species_count)
terr_temp$stas <- scale(terr_temp$base_tas)
terr_temp$sdiff <- scale(terr_temp$diff)
terr_temp<- terr_temp[complete.cases(terr_temp),]


terr_lme_temp<-lme(Thermophilisation~swarming*(sniche*sbody+stas+sspr)+sdiff,
                   data = terr_temp, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(terr_lme_temp)
anova(terr_lme_temp)

terr_temp$Resid <- resid(terr_lme_temp)
SD2_terr_temp<-2*sd(resid(terr_lme_temp))
SD2_terr_temp

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
terr_temp$Outs<-ifelse(abs(terr_temp$Resid)>SD2_terr_temp, 1, 0)
terr11_temp <- terr_temp[terr_temp$Outs == 0,]
terr11_temp$swarming <- scale(terr11_temp$warming)
terr11_temp$sniche <- scale(terr11_temp$base_niche_breadth)
terr11_temp$sbody <- scale(terr11_temp$base_Body)
terr11_temp$ssr <- scale(terr11_temp$species_count)
terr11_temp$stas <- scale(terr11_temp$base_tas)
terr11_temp$sdiff <- scale(terr11_temp$diff)
terr_lme1_temp<-lme(Thermophilisation~swarming*(sniche*sbody+stas+sspr)+sdiff,
                    data = terr11_temp, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(terr_lme1_temp)
# 
terr_temp_data <- terr_lme1_temp$data
terr_coefs_temp <- coefTable(terr_lme1_temp, full=F)
terr_coefnames_temp <- row.names(terr_coefs_temp)
terr_coefs_temp <- as.data.frame(terr_coefs_temp)
terr_coefs_temp <- mutate(terr_coefs_temp,
                          coefficient = terr_coefnames_temp,
                          t = Estimate / `Std. Error`,
                          p = round(pt(abs(t), df = nrow(terr_coefs_temp)-1, lower.tail = FALSE),3),
                          lower95 = Estimate - 1.96 * `Std. Error`,
                          upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_terr_temp <-
  terr_coefs_temp %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sniche:sbody" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sniche:sbody" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  coord_flip() +
  labs(title = "Terrestrial")+
  theme_bw()+ theme(legend.position = "none")
plot_terr_temp

fresh_temp <- d23[d23$Realm == "Freshwater",]
names(fresh_temp)
fresh_temp <- fresh_temp[!fresh_temp$taxa == "Phytoplankton",]
fresh_temp$swarming <- scale(fresh_temp$warming)
fresh_temp$sniche <- scale(fresh_temp$base_niche_breadth)
fresh_temp$sbody <- scale(fresh_temp$base_Body)
fresh_temp$ssr <- scale(fresh_temp$species_STI)
fresh_temp$stas <- scale(fresh_temp$base_tas)
fresh_temp$sdiff <- scale(fresh_temp$diff)
#

fresh_temp<- fresh_temp[!is.na(fresh_temp$base_Body),]
fresh_temp<- fresh_temp[!is.na(fresh_temp$ID),]
fresh_temp<- fresh_temp[!is.na(fresh_temp$lat),]
fresh_temp$taxa <- as.factor(fresh_temp$taxa)
fresh_temp$ID <- as.factor(fresh_temp$ID)
# 
fresh_lme_temp<-lme(Thermophilisation~swarming*(sniche*sbody+stas+ssr)+sdiff,
                    data = fresh_temp, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(maxIter=100,opt = c("optim")))

summary(fresh_lme_temp)

fresh_temp$Resid <- resid(fresh_lme_temp)
SD2_fresh_temp<-2*sd(resid(fresh_lme_temp))
SD2_fresh_temp
#
# # Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
fresh_temp$Outs<-ifelse(abs(fresh_temp$Resid)>SD2_fresh_temp, 1, 0)
fresh11_temp <- fresh_temp[fresh_temp$Outs == 0,]
fresh11_temp$taxa <- droplevels(fresh11_temp$taxa)
#
fresh11_temp$swarming <- scale(fresh11_temp$warming)
fresh11_temp$sniche <- scale(fresh11_temp$base_niche_breadth)
fresh11_temp$sbody <- scale(fresh11_temp$base_Body)
fresh11_temp$ssr <- scale(fresh11_temp$species_count)
fresh11_temp$stas <- scale(fresh11_temp$base_tas)
fresh11_temp$sdiff <- scale(fresh11_temp$diff)
fresh11_temp<- fresh11_temp[!is.na(fresh11_temp$Thermophilisation),]
fresh11_temp<- fresh11_temp[!is.na(fresh11_temp$warming),]
fresh11_temp<- fresh11_temp[!is.na(fresh11_temp$base_Body),]

fresh_lme1_temp<-lme(Thermophilisation~swarming*(sniche*sbody+stas+ssr)+sdiff,
                     data = fresh11_temp, random=list(taxa=~1,ID=~1),correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = c("optim")))
summary(fresh_lme1_temp)
r.squaredGLMM(fresh_lme1_temp)
fresh_data_temp <- fresh_lme1_temp$data

fresh_data_temp<- fresh_lme1_temp$data
fresh_coefs_temp <- coefTable(fresh_lme1_temp, full=F)
fresh_coefnames_temp <- row.names(fresh_coefs_temp)
fresh_coefs_temp <- as.data.frame(fresh_coefs_temp)
fresh_coefs_temp <- mutate(fresh_coefs_temp,
                           coefficient = fresh_coefnames_temp,
                           t = Estimate / `Std. Error`,
                           p = round(pt(abs(t), df = nrow(fresh_coefs_temp)-1, lower.tail = FALSE),3),
                           lower95 = Estimate - 1.96 * `Std. Error`,
                           upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_fresh_temp <-
  fresh_coefs_temp %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "ssr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sniche:sbody" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:ssr" = "B_Warming:species_richness",
                                     "swarming:sniche:sbody" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Freshwater")+
  theme_bw()+ theme(legend.position = "none")

plot_fresh_temp




Birds1_temp <- d23[d23$taxa == "Birds",]

names(Birds1_temp)
Birds1_temp$swarming <- scale(Birds1_temp$warming)
Birds1_temp$sbody <- scale(Birds1_temp$base_Body)
Birds1_temp$sniche <- scale(Birds1_temp$base_niche_breadth)
Birds1_temp$sspr <- scale(Birds1_temp$species_count)
Birds1_temp$stas <- scale(Birds1_temp$base_tas)
Birds1_temp$sdiff <- scale(Birds1_temp$diff)

# 
birds_lme1_temp<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                     data = Birds1_temp, random=~1|ID,correlation=corGaus(form = ~ lat + lon),
                     control = lmeControl(maxIter=100,opt = c("optim")))
summary(birds_lme1_temp)
#
Birds1_temp$Resid<-resid(birds_lme1_temp)
# Find out what 2 standard deviations is and save it to SD2
SD2_birds_temp<-2*sd(resid(birds_lme1_temp))
SD2_birds_temp
#
# # Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
Birds1_temp$Outs<-ifelse(abs(Birds1_temp$Resid)>SD2_birds_temp, 1, 0)
Birds11_temp <- Birds1_temp[Birds1_temp$Outs == 0,]
Birds11_temp$swarming <- scale(Birds11_temp$warming)
Birds11_temp$sbody <- scale(Birds11_temp$base_Body)
Birds11_temp$sniche <- scale(Birds11_temp$base_niche_breadth)
Birds11_temp$sspr <- scale(Birds11_temp$species_count)
Birds11_temp$stas <- scale(Birds11_temp$base_tas)
Birds11_temp$sdiff <- scale(Birds11_temp$diff)
#
birds_lme11<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                 data = Birds11_temp, random=~1|ID,correlation=corGaus(form = ~ lat + lon),
                 control = lmeControl(maxIter=100,opt = c("optim")))
summary(birds_lme11_temp)
r.squaredGLMM(birds_lme11_temp)

bird_coefs_temp <- coefTable(birds_lme11_temp, full=F)
bird_coefnames_temp <- row.names(bird_coefs_temp)
bird_coefs_temp <- as.data.frame(bird_coefs_temp)
bird_coefs_temp <- mutate(bird_coefs_temp,
                          coefficient = bird_coefnames_temp,
                          t = Estimate / `Std. Error`,
                          p = round(pt(abs(t), df = nrow(bird_coefs_temp)-1, lower.tail = FALSE),3),
                          lower95 = Estimate - 1.96 * `Std. Error`,
                          upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_bird_temp <-
  bird_coefs_temp %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Birds")+
  theme_bw()+ theme(legend.position = "none")

plot_bird_temp

####
Mammals1 <- d23[d23$taxa == "Mammals",]
Mammals1$swarming <- scale(Mammals1$warming)
Mammals1$sbody <- scale(Mammals1$base_Body)
Mammals1$sniche <- scale(Mammals1$base_niche_breadth)
Mammals1$sspr <- scale(Mammals1$species_count)
Mammals1$stas <- scale(Mammals1$base_tas)
Mammals1$sdiff <- scale(Mammals1$diff)

library(nlme)
mammals_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                 data = Mammals1,random= ~1|ID,correlation=corGaus(form = ~ lat + lon))
summary(mammals_lme)
hist(mammals_lme$residuals)

Mammals1$Resid<-resid(mammals_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_mammals<-2*sd(resid(mammals_lme))
SD2_mammals
# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
Mammals1$Outs<-ifelse(abs(Mammals1$Resid)>SD2_mammals, 1, 0)

Mammals11 <- Mammals1[Mammals1$Outs == 0,]
Mammals11$swarming <- scale(Mammals11$warming)
Mammals11$sbody <- scale(Mammals11$base_Body)
Mammals11$sniche <- scale(Mammals11$base_niche_breadth)
Mammals11$sspr <- scale(Mammals11$species_count)
Mammals11$stas <- scale(Mammals11$base_tas)
Mammals11$sdiff <- scale(Mammals11$diff)

mammals_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                  data = Mammals11,random= ~1|ID, correlation=corGaus(form = ~ lat +lon), control = lmeControl(opt = "optim"))
summary(mammals_lme1)

ma_coefs <- coefTable(mammals_lme1, full=F)
coefnames <- row.names(ma_coefs)
ma_coefs <- as.data.frame(ma_coefs)
ma_coefs <- mutate(ma_coefs,
                   coefficient = coefnames,
                   t = Estimate / `Std. Error`,
                   p = round(pt(abs(t), df = nrow(ma_coefs)-1, lower.tail = FALSE),3),
                   lower95 = Estimate - 1.96 * `Std. Error`,
                   upper95 = Estimate + 1.96 * `Std. Error`)
plot_mammals_temp <-
  ma_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Mammals")+
  theme_bw()+ theme(legend.position = "none")
plot_mammals_temp


insects1 <- d23[d23$taxa == "Terrestrial_insects",]
insects1$swarming <- scale(insects1$warming)
insects1$sbody <- scale(insects1$base_Body)
insects1$sniche <- scale(insects1$base_niche_breadth)
insects1$sspr <- scale(insects1$species_count)
insects1$stas <- scale(insects1$base_tas)
insects1$sdiff <- scale(insects1$diff)
insects1 <- insects1[!is.na(insects1$sbody),]
insects1 <- insects1[complete.cases(insects1),]

insects_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                 data = insects1,random=~1|ID, correlation=corGaus(form = ~ lat +lon), control = lmeControl(opt = "optim"))
summary(insects_lme)
hist(insects_lme$residuals)
insects1$Resid <- resid(insects_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_insect<-2*sd(resid(insects_lme))
SD2_insect
# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
insects1$Outs<-ifelse(abs(insects1$Resid)>SD2_insect, 1, 0)

insects11 <- insects1[insects1$Outs == 0,]
insects11$swarming <- scale(insects11$warming)
insects11$sbody <- scale(insects11$base_Body)
insects11$sniche <- scale(insects11$base_niche_breadth)
insects11$sspr <- scale(insects11$species_count)
insects11$stas <- scale(insects11$base_tas)
insects11$sdiff <- scale(insects11$diff)
insects11 <- insects11[!is.na(insects11$sbody),]

insects_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                  data = insects11,random = ~1|ID, correlation=corGaus(form = ~ lat+lon))
summary(insects_lme1)
r.squaredGLMM(insects_lme1)

insect_coefs <- coefTable(insects_lme1, full=F)
insect_coefnames <- row.names(insect_coefs)
insect_coefs <- as.data.frame(insect_coefs)
insect_coefs <- mutate(insect_coefs,
                       coefficient = insect_coefnames,
                       t = Estimate / `Std. Error`,
                       p = round(pt(abs(t), df = nrow(insect_coefs)-1, lower.tail = FALSE),3),
                       lower95 = Estimate - 1.96 * `Std. Error`,
                       upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_insects_temp <-
  insect_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Terrestrial Insects")+
  theme_bw()+ theme(legend.position = "none")

plot_insects_temp

plants1 <- d23[d23$taxa == "Plants",]
names(plants1)

plants1$swarming <- scale(plants1$warming)
plants1$sbody <- scale(plants1$base_Body)
plants1$sniche <- scale(plants1$base_niche_breadth)
plants1$sspr <- scale(plants1$species_count)
plants1$stas <- scale(plants1$base_tas)
plants1$sdiff <- scale(plants1$diff)

plants_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                data = plants1, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon),
                control = glsControl(opt = "optim"))
summary(plants_lme)
hist(plants_lme$residuals)

plants1$Resid<-resid(plants_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_plant<-2*sd(resid(plants_lme))
SD2_plant

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
plants1$Outs<-ifelse(abs(plants1$Resid)>SD2_plant, 1, 0)

plants11 <- plants1[plants1$Outs == 0,]
plants11$swarming <- scale(plants11$warming)
plants11$sbody <- scale(plants11$base_Body)
plants11$sniche <- scale(plants11$base_niche_breadth)
plants11$sspr <- scale(plants11$species_count)
plants11$stas <- scale(plants11$base_tas)
plants11$sdiff <- scale(plants11$diff)

plants_lme11<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
                  data = plants11,random=~1|ID, correlation=corGaus(1,form = ~ lat + lon),
                  control = lmeControl(opt = "optim"))
summary(plants_lme11)
r.squaredGLMM(plants_lme11)

plant_coefs <- coefTable(plants_lme11, full=F)
plant_coefnames <- row.names(plant_coefs)
plant_coefs <- as.data.frame(plant_coefs)
plant_coefs <- mutate(plant_coefs,
                      coefficient = plant_coefnames,
                      t = Estimate / `Std. Error`,
                      p = round(pt(abs(t), df = nrow(plant_coefs)-1, lower.tail = FALSE),3),
                      lower95 = Estimate - 1.96 * `Std. Error`,
                      upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_plant_temp <-
  plant_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Plants")+
  theme_bw()+ theme(legend.position = "none")

plot_plant_temp


fish1 <- d3[d3$taxa == "Fish",]
fish1$swarming <- scale(fish1$warming)
fish1$sbody <- scale(fish1$base_Body)
fish1$sniche <- scale(fish1$base_niche_breadth)
fish1$sspr <- scale(fish1$species_STI)
fish1$stas <- scale(fish1$base_tas)
fish1$sdiff <- scale(fish1$diff)

fish_lme<-lme(Thermophilisation~swarming*(sbody*sniche+sspr+stas)+sdiff,
              data = fish1, random=~1|ID, correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(fish_lme)

fish1$Resid<-resid(fish_lme)

# Find out what 2 standard deviations is and save it to SD2
SD2_fish1<-2*sd(resid(fish_lme))
SD2_fish1

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
fish1$Outs<-ifelse(abs(fish1$Resid)>SD2_fish1, 1, 0)
fish11 <- fish1[fish1$Outs == 0,]
fish11$swarming <- scale(fish11$warming)
fish11$sbody <- scale(fish11$base_Body)
fish11$sniche <- scale(fish11$base_niche_breadth)
fish11$sspr <- scale(fish11$species_STI)
fish11$stas <- scale(fish11$base_tas)
fish11$sdiff <- scale(fish11$diff)
# 
fish_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
               data = fish11, random=~1|ID, correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(fish_lme1)

r.squaredGLMM(fish_lme1)

fish_data_temp<- fish_lme1$data
fish_coefs <- coefTable(fish_lme1, full=F)
fish_coefnames <- row.names(fish_coefs)
fish_coefs <- as.data.frame(fish_coefs)
fish_coefs <- mutate(fish_coefs,
                     coefficient = fish_coefnames,
                     t = Estimate / `Std. Error`,
                     p = round(pt(abs(t), df = nrow(fish_coefs)-1, lower.tail = FALSE),3),
                     lower95 = Estimate - 1.96 * `Std. Error`,
                     upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_fish_temp <-
  fish_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red"))+
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Fish")+
  theme_bw()+ theme(legend.position = "none")

plot_fish_temp


phy1 <- d23[d23$taxa == "Phytoplankton",]
phy1$swarming <- scale(phy1$warming)
phy1$sbody <- scale(phy1$base_Body)
phy1$sniche <- scale(phy1$base_niche_breadth)
phy1$sspr <- scale(phy1$species_count)
phy1$stas <- scale(phy1$base_tas)
phy1$sdiff <- scale(phy1$diff)

phy1 <-phy1[!is.na(phy1$sbody),]
phy_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
             data = phy1, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon))
summary(phy_lme)


phy1$Resid<-resid(phy_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_phy1<-2*sd(resid(phy_lme))
SD2_phy1
# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
phy1$Outs<-ifelse(abs(phy1$Resid)>SD2_phy1, 1, 0)
phy11 <- phy1[phy1$Outs == 0,]
phy11$swarming <- scale(phy11$warming)
phy11$sbody <- scale(phy11$base_Body)
phy11$sniche <- scale(phy11$base_niche_breadth)
phy11$sspr <- scale(phy11$species_count)
phy11$stas <- scale(phy11$base_tas)
phy11$sdiff <- scale(phy11$diff)
phy_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
              data = phy11,random=~1|ID, correlation=corGaus(1,form = ~ lat + lon))
summary(phy_lme1)

phy_coefs <- coefTable(phy_lme1, full=F)
phy_coefnames <- row.names(phy_coefs)
phy_coefs <- as.data.frame(phy_coefs)
phy_coefs <- mutate(phy_coefs,
                    coefficient = phy_coefnames,
                    t = Estimate / `Std. Error`,
                    p = round(pt(abs(t), df = nrow(phy_coefs)-1, lower.tail = FALSE),3),
                    lower95 = Estimate - 1.96 * `Std. Error`,
                    upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_phy_temp <-
  phy_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red"))+
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Phytoplankton")+
  theme_bw()+ theme(legend.position = "none")
plot_phy_temp




zoo1 <- d23[d23$taxa == "Zooplankton",]

zoo1$swarming <- scale(zoo1$warming)
zoo1$sbody <- scale(zoo1$base_Body)
zoo1$sniche <- scale(zoo1$base_niche_breadth)
zoo1$sspr <- scale(zoo1$species_count)
zoo1$stas <- scale(zoo1$base_tas)
zoo1$sdiff <- scale(zoo1$diff)

zoo1<- zoo1[!is.na(zoo1$sbody),]
zoo1 <- zoo1[complete.cases(zoo1),]
zoo_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
             data = zoo1, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon),
             control = lmeControl(opt = "optim"),na.action=na.omit)
summary(zoo_lme)
hist(zoo_lme$residuals)
zoo1$Resid<-resid(zoo_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_zoo1<-2*sd(resid(zoo_lme))
SD2_zoo1

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
zoo1$Outs<-ifelse(abs(zoo1$Resid)>SD2_zoo1, 1, 0)
zoo11 <- zoo1[zoo1$Outs == 0,]

zoo11$swarming <- scale(zoo11$warming)
zoo11$sbody <- scale(zoo11$base_Body)
zoo11$sniche <- scale(zoo11$base_niche_breadth)
zoo11$sspr <- scale(zoo11$species_count)
zoo11$stas <- scale(zoo11$base_tas)
zoo11$sdiff <- scale(zoo11$diff)

zoo_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
              data = zoo11, random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(zoo_lme1)
r.squaredGLMM(zoo_lme1)

zoo_coefs <- coefTable(zoo_lme1, full=F)
zoo_coefnames <- row.names(zoo_coefs)
zoo_coefs <- as.data.frame(zoo_coefs)
zoo_coefs <- mutate(zoo_coefs,
                    coefficient = zoo_coefnames,
                    t = Estimate / `Std. Error`,
                    p = round(pt(abs(t), df = nrow(zoo_coefs)-1, lower.tail = FALSE),3),
                    lower95 = Estimate - 1.96 * `Std. Error`,
                    upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_zoo_temp <-
  zoo_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","blue","red")) + 
  scale_color_manual(values=c("grey","blue","red")) +
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Zooplankton")+
  theme_bw()+ theme(legend.position = "none")

plot_zoo_temp



aqua1 <- d23[d23$taxa == "Aquatic_insects",]
aqua1<- unique(aqua1)
aqua1$swarming <- scale(aqua1$warming)
aqua1$sbody <- scale(aqua1$base_Body)
aqua1$sniche <- scale(aqua1$base_niche_breadth)
aqua1$sspr <- scale(aqua1$species_count)
aqua1$stas <- scale(aqua1$base_tas)
aqua1$sdiff <- scale(aqua1$diff)
aqua1<- aqua1[!is.nan(aqua1$base_Body),]
aqua1 <- aqua1[complete.cases(aqua1),]
aqua_lme<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
              data = aqua1,random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(aqua_lme)

aqua1$Resid<-resid(aqua_lme)
# Find out what 2 standard deviations is and save it to SD2
SD2_aqua1<-2*sd(resid(aqua_lme))
SD2_aqua1

# Make DF$Outs 1 if a residual is 2 st. deviations from the mean, 0 otherwise
aqua1$Outs<-ifelse(abs(aqua1$Resid)>SD2_aqua1, 1, 0)
aqua11 <- aqua1[aqua1$Outs == 0,]
aqua11$swarming <- scale(aqua11$warming)
aqua11$sbody <- scale(aqua11$base_Body)
aqua11$sniche <- scale(aqua11$base_niche_breadth)
aqua11$sspr <- scale(aqua11$species_count)
aqua11$stas <- scale(aqua11$base_tas)
aqua11$sdiff <- scale(aqua11$diff)

aqua_lme1<-lme(Thermophilisation~swarming*(sbody*sniche+stas+sspr)+sdiff,
               data = aqua11,random=~1|ID,correlation=corGaus(1,form = ~ lat + lon), control = lmeControl(opt = "optim"))
summary(aqua_lme1)
r.squaredGLMM(aqua_lme1)

aqua_coefs <- coefTable(aqua_lme1, full=F)
aqua_coefnames <- row.names(aqua_coefs)
aqua_coefs <- as.data.frame(aqua_coefs)
aqua_coefs <- mutate(aqua_coefs,
                     coefficient = aqua_coefnames,
                     t = Estimate / `Std. Error`,
                     p = round(pt(abs(t), df = nrow(aqua_coefs)-1, lower.tail = FALSE),3),
                     lower95 = Estimate - 1.96 * `Std. Error`,
                     upper95 = Estimate + 1.96 * `Std. Error`)
# 
plot_aqua_temp <-
  aqua_coefs %>% 
  filter(coefficient %ni% c("(Intercept)")) %>%  
  mutate(coefficient = dplyr::recode(coefficient , 
                                     "swarming" = "L_Warming",
                                     "sbody" = "K_Body size",
                                     "sniche" = "J_Thermal niche breadth",
                                     "stas" = "I_Base line temperature",
                                     "sspr" = "H_Base line species richness",
                                     "sdiff" = "G_Time_series_length",
                                     "sbody:sniche" = "F_Body size:Thermal niche breadth",
                                     "swarming:sbody" = "E_Warming:Body size",
                                     "swarming:sniche" = "D_Warming:Thermal niche breadth",
                                     "swarming:stas" = "C_Warming:Temperature",
                                     "swarming:sspr" = "B_Warming:species_richness",
                                     "swarming:sbody:sniche" = "A_Warming:Body size:Thermal niche breadth"
  )) %>% 
  #mutate(coefficient = reorder(coefficient, Estimate)) %>% 
  mutate(Sign = ifelse(lower95>0 | upper95<0 ,"sign","ns"),
         Col = ifelse(Sign=="sign"&Estimate>0,"red",
                      ifelse(Sign=="sign"&Estimate<0,"grey","blue"))) %>% 
  ggplot() + aes(x=coefficient,y=Estimate,col=Col,
                 fill=Col) + 
  geom_hline(yintercept = 0,lty=2) + 
  geom_errorbar(aes(ymin = lower95 , ymax= upper95),width=0,size=1) +
  geom_point(size=4,pch=21,col="black") +
  theme(axis.text.x=element_text(angle = 45, hjust = 1),legend.position = "none") +
  scale_fill_manual(values=c("grey","red","blue")) + 
  scale_color_manual(values=c("grey","red","blue"))+
  xlab("Explanatory Variables") + ylab("Coefficient Estimates") +
  #scale_y_continuous(limits = c(-0.1,0.1),breaks = seq(-2.5,1.5,by=0.5)) +
  coord_flip() +
  labs(title = "Aquatic insects")+
  theme_bw()+ theme(legend.position = "none")

plot_aqua_temp



library(ggpubr)
ggarrange(plot_terr_temp,plot_plant_temp,plot_insects_temp,plot_bird_temp,plot_fresh_temp,
          plot_zoo_temp,plot_aqua_temp,plot_fish_temp,
          labels = c("a", "b","c","d","e","f","g","h"),
          ncol = 4, nrow = 2)


# Extended Data Figure 8 ####

abundance_all<-readRDS("../Data/all_abundacne.Rdata")

CTI_biotime<-ddply(abundance_all,.(Year,Taxa,lat,lon),summarise, CTI = mean(overall_niche, na.rm=T),
                   CTI.wd = weighted.mean(overall_niche,abundance, na.rm=T))
names(CTI_biotime)
unique(CTI_biotime$taxa)
exc <- c("Snail_Gastro", "Reptiles","Amphibians","Freshwater_plants")

CTI_biotime <- subset(CTI_biotime,!CTI_biotime$Taxa%in%exc)

CTI_biotime$Realm[CTI_biotime$Taxa == "Plants"]<- "Terrestrial"
CTI_biotime$Realm[CTI_biotime$Taxa == "Birds"]<- "Terrestrial"
CTI_biotime$Realm[CTI_biotime$Taxa == "Mammals"]<- "Terrestrial"
CTI_biotime$Realm[CTI_biotime$Taxa == "Terrestrial insects"]<- "Terrestrial"
CTI_biotime$Realm[CTI_biotime$Taxa == "Phytoplankton"]<- "Freshwater"
CTI_biotime$Realm[CTI_biotime$Taxa == "Zooplankton"]<- "Freshwater"
CTI_biotime$Realm[CTI_biotime$Taxa == "Aquatic_insects"]<- "Freshwater"
CTI_biotime$Realm[CTI_biotime$Taxa == "Fish"]<- "Freshwater"

CTI_biotime$Realm <- factor(CTI_biotime$Realm,      # Reordering group factor levels
                            levels = c("Terrestrial","Freshwater"))
options(scipen=2)

freshwater_wtd<-CTI_biotime[CTI_biotime$Realm == "Freshwater",]
terrestrial_wtd<-CTI_biotime[CTI_biotime$Realm == "Terrestrial",]
names(freshwater_wtd)

tr1<- ggplot(terrestrial_wtd, aes(x=CTI, y=CTI.wd)) +
  geom_point(col= "green3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE,col="black")+
  stat_cor()+
  ylab("")+
  xlab("")+
  theme_minimal()+xlim(0,30)+ylim(0,30)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none")+ggtitle("Terrestrial")

fr1<- ggplot(freshwater_wtd, aes(x=CTI, y=CTI.wd)) +
  geom_point(col= "dodgerblue3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE, col="black")+
  stat_cor()+
  ylab("")+
  xlab("")+
  theme_minimal()+xlim(0,30)+ylim(0,30)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none")+ggtitle("Freshwater")


library(ggpubr)
library(grid)
figures6<-ggarrange(tr1,fr1,
                    labels = c("a", "b"),
                    ncol = 2, nrow = 1,common.legend = TRUE, legend = "bottom",
                    align = "hv",font.label = list(size = 10, 
                                                   color = "black", face = "bold", family = NULL, position = "top"))

annotate_figure(figures6, left = textGrob("Community temperature index weighted (°C)", rot = 90, vjust = 1, gp = gpar(cex = 1)),
                bottom = textGrob("Community temperature index (°C)", gp = gpar(cex = 1)))



# Extended Figure Data 9, 10 ####

birds01<-readRDS("../Data/Birds_Gbif.RData")
fs8a<-ggplot(birds01, aes(x=overall_niche, y=range_mean)) +
  geom_point(col= "green3",alpha=0.6)+
  stat_smooth(method="lm",se=TRUE,col="black")+
  stat_cor()+
  xlab("")+
  ylab("")+
  theme_minimal()+
  theme(text = element_text(size=12))+
  theme(legend.position = "none")+ggtitle("Birds")

# Figure GBIF and range map for plants
plants_elen1<-readRDS("../Data/plants_elen.RData")

fs8b<- ggplot(plants_elen1, aes(x=overall_niche, y=YearMeanMean)) +
  geom_point(col= "green3",alpha=0.6)+
  stat_smooth(method="lm",se=TRUE,col="black")+
  stat_cor()+
  xlab("")+
  ylab("")+
  theme_minimal()+
  theme(text = element_text(size=12))+
  theme(legend.position = "none")+ggtitle("Plants")



figures7<-ggarrange(fs8a,fs8b,
                    labels = c("a", "b"),
                    ncol = 2, nrow = 1,common.legend = TRUE, legend = "bottom",
                    align = "hv",font.label = list(size = 10, 
                                                   color = "black", face = "bold", family = NULL, position = "top"))

annotate_figure(figures7, left = textGrob("STI based upon range maps", rot = 90, vjust = 1, gp = gpar(cex = 1)),
                bottom = textGrob("STI based upon GBIF", gp = gpar(cex = 1)))





# Figure Ellenberg's indicator value and GBIF CTI
plants_elen<-readRDS("../Data/plants.Ellen.RData")
## to calculate the CTI per site per year
CTI_site_plants<-ddply(plants_elen,.(ID_Site,Year),summarise, CTI = mean(overall_niche,na.rm=TRUE),
                       temp_cat = mean(temp_cat,na.rm=TRUE))
pl1<-ggplot(CTI_site_plants, aes(x=CTI, y=temp_cat)) +
  geom_point(col= "green3",alpha=0.6)+
  stat_smooth(method="lm",se=TRUE,col="black")+
  stat_cor()+
  xlab("Community temperature index 
       (distributional data, °C) ")+
  ylab("Community temperature index 
       (Ellenberg Indicator values)")+
  theme_minimal()+
  theme(text = element_text(size=12))+
  theme(legend.position = "none")+ggtitle("Plants")


# Extended Figure Data 11 ####
terr_species<-readRDS("../Data/Figure_S11.terr.RData")
fresh_species<-readRDS("../Data/Figure_S11.fresh.RData")

ggpairs(terr_species[, c("niche_1990","niche_2000","niche_2010","niche_2020")], title= "Terrestrial") 
ggpairs(fresh_species[, c("niche_1990","niche_2000","niche_2010","niche_2020")], title= "Freshwater") 


# Extended Figure Data 12 ####

mean_data<-readRDS("../Data/Mean_data.RData")

freshwater1 <- mean_data[mean_data$Realm=="Freshwater",]
terrestrial1 <-mean_data[mean_data$Realm=="Terrestrial",]
names(freshwater1)
f1<-freshwater1 %>%
  ggplot( aes(x=mean_tas, y=mean_cti, colour=taxa))+
  stat_smooth(method="lm",se=TRUE)+
  stat_cor()+
  xlab("")+ylab("")+
  theme_minimal()+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"))+ggtitle("Freshwater")

f2<-f1 + scale_color_manual(values = c("#52854C","#56B4E9","#D16103", "#4E84C4"))

p1<-terrestrial1 %>%
  ggplot( aes(x=mean_tas, y=mean_cti, colour=taxa))+
  stat_smooth(method="lm",se=TRUE)+
  stat_cor()+xlab("")+ylab("")+
  theme_minimal()+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"))+ggtitle("Terrestrial")
p2<-p1 + scale_color_manual(values = c("#52854C", "#D16103","#56B4E9","#4E84C4"))


figures11<-ggarrange(p2,f2,
                     labels = c("a", "b"),
                     ncol = 2, nrow = 1,common.legend = TRUE, legend = "right",
                     align = "hv",font.label = list(size = 10, 
                                                    color = "black", face = "bold", family = NULL, position = "top"))

annotate_figure(figures11, left = textGrob("Mean site-level CTI across time (°C)", rot = 90, vjust = 1, gp = gpar(cex = 1)),
                bottom = textGrob("Mean site-level temperatures across time (°C)", gp = gpar(cex = 1)))


# Extended Data Figure 13 ####

all_cti<-readRDS( "../Data/all_cti_Figure_13.RData")
birds<- all_cti[all_cti$taxa == "Birds",]
plants<- all_cti[all_cti$taxa == "Plants",]
insects<- all_cti[all_cti$taxa == "Terrestrial_insects",]
mammals<- all_cti[all_cti$taxa == "Mammals",]
phytoplankton<- all_cti[all_cti$taxa == "Phytoplankton",]
zoo<- all_cti[all_cti$taxa == "Zooplankton",]
aqua_in<- all_cti[all_cti$taxa == "Aquatic_insects",]
fish<- all_cti[all_cti$taxa == "Fish",]

ctib1<- ggplot(birds, aes(x=CTI, y=CTI_exc)) +
  geom_point(col= "green3", alpha = 0.2)+
  stat_smooth(method="lm",se=TRUE, col= "black")+
  ylab("")+
  xlab("")+stat_cor()+
  theme_minimal()+xlim(0,30)+ylim(0,30)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none",plot.title = element_text(hjust = 0.5))+ggtitle("Birds")

ctip1<- ggplot(plants, aes(x=CTI, y=CTI_exc)) +
  geom_point(col= "green3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE, col= "black")+
  ylab("")+
  xlab("")+stat_cor()+
  theme_minimal()+xlim(-5,30)+ylim(-5,30)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none",plot.title = element_text(hjust = 0.5))+ggtitle("Plants")

ctii1<- ggplot(insects, aes(x=CTI, y=CTI_exc)) +
  geom_point(col= "green3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE, col= "black")+
  ylab("")+
  xlab("")+stat_cor()+
  theme_minimal()+xlim(0,30)+ylim(0,30)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none",plot.title = element_text(hjust = 0.5))+ggtitle("Terrestrial insects")

ctim1<- ggplot(mammals, aes(x=CTI, y=CTI_exc)) +
  geom_point(col= "green3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE, col= "black")+
  ylab("")+
  xlab("")+stat_cor()+
  theme_minimal()+xlim(0,30)+ylim(0,30)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none",plot.title = element_text(hjust = 0.5))+ggtitle("Mammals")

ctiph1<- ggplot(phytoplankton, aes(x=CTI, y=CTI_exc)) +
  geom_point(col= "dodgerblue3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE, col= "black")+
  ylab("")+
  xlab("")+stat_cor()+
  theme_minimal()+xlim(9,15)+ylim(9,15)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none",plot.title = element_text(hjust = 0.5))+ggtitle("Phytoplankton")

ctiz1<- ggplot(zoo, aes(x=CTI, y=CTI_exc)) +
  geom_point(col= "dodgerblue3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE, col= "black")+
  ylab("")+
  xlab("")+stat_cor()+
  theme_minimal()+xlim(0,20)+ylim(0,20)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none",plot.title = element_text(hjust = 0.5))+ggtitle("Zooplankton")

ctiaqi1<- ggplot(aqua_in, aes(x=CTI, y=CTI_exc)) +
  geom_point(col= "dodgerblue3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE, col= "black")+
  ylab("")+
  xlab("")+stat_cor()+
  theme_minimal()+xlim(5,20)+ylim(5,20)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none",plot.title = element_text(hjust = 0.5))+ggtitle("Aquatic insects")

ctif1<- ggplot(fish, aes(x=CTI, y=CTI_exc)) +
  geom_point(col= "dodgerblue3",alpha=0.2)+
  stat_smooth(method="lm",se=TRUE, col= "black")+
  ylab("")+
  xlab("")+stat_cor()+
  theme_minimal()+xlim(0,30)+ylim(0,30)+
  theme(text = element_text(size=12))+
  theme(legend.position = "none",plot.title = element_text(hjust = 0.5))+ggtitle("Fish")


figuresS13<-ggarrange(ctip1,ctii1,ctib1,ctim1,ctiph1,ctiz1,ctiaqi1,ctif1,
                      labels = c("a", "b","c","d","e","f","g","h"),
                      ncol = 4, nrow = 2,common.legend = TRUE, legend = "bottom",
                      align = "hv",font.label = list(size = 10, 
                                                     color = "black", face = "bold", family = NULL, position = "top"))

annotate_figure(figuresS13, left = textGrob("Community temperature index based upon
                                              more than 5 occurrence records", rot = 90, vjust = 1, gp = gpar(cex = 1.3)),
                bottom = textGrob("Community temperature index including all 
                                              occurrence records", gp = gpar(cex = 1.3)))

# Extended Data Figure 14 ####

d1 <- unique(d2[,c("uniqu_cord","base_niche_breadth","Realm","base_Body","base_tas","warming","diff","species_count")])
realms <- c("Terrestrial", "Freshwater")  
data_list <- lapply(realms, function(r) d1 %>%
                      filter(Realm == r) %>%
                      drop_na(base_Body) %>%  # Remove rows with NAs in Body_size
                      select(warming, base_tas, base_Body, base_niche_breadth, diff,species_count ))

cor_matrices <- lapply(data_list, function(data) cor(data))

plot_correlation_matrix <- function(cor_matrix, realm) {
  cor_df <- as.data.frame(as.table(cor_matrix))
  
  ggplot(cor_df, aes(Var1, Var2, fill = Freq)) +
    geom_tile() +
    geom_text(aes(label = sprintf("%.2f", Freq)), vjust = 1) +
    scale_fill_gradient(low = "white", high = "steelblue") +
    labs(title =  realm,
         x = "Variables",
         y = "Variables") +
    theme_minimal() +
    theme(axis.text.x = element_text(angle = 45, hjust = 1))
}

cor_plot_list <- mapply(plot_correlation_matrix, cor_matrices, realms, SIMPLIFY = FALSE)


correlation_plots<-wrap_plots(cor_plot_list)

correlation_plots

